# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/compiled.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8dbtlabs/proto/public/v1/events/fusion/log/compiled.proto\x12\x1bv1.public.events.fusion.log\"!\n\x12\x43ompiledCodeInline\x12\x0b\n\x03sql\x18\x01 \x01(\tB>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.compiled_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_COMPILEDCODEINLINE']._serialized_start=89
  _globals['_COMPILEDCODEINLINE']._serialized_end=122
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UserState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_STATE_UNREGISTERED: _UserState.ValueType  # 0
    """User is not registered"""
    USER_STATE_REGISTERED: _UserState.ValueType  # 1
    """User is registered but not verified"""
    USER_STATE_VERIFIED: _UserState.ValueType  # 2
    """User is registered and verified"""
    USER_STATE_EXPIRED: _UserState.ValueType  # 3
    """User's registration has expired"""
    USER_STATE_VERIFICATION_ERROR: _UserState.ValueType  # 4
    """Error occurred during verification"""

class UserState(_UserState, metaclass=_UserStateEnumTypeWrapper):
    """User state enum"""

USER_STATE_UNREGISTERED: UserState.ValueType  # 0
"""User is not registered"""
USER_STATE_REGISTERED: UserState.ValueType  # 1
"""User is registered but not verified"""
USER_STATE_VERIFIED: UserState.ValueType  # 2
"""User is registered and verified"""
USER_STATE_EXPIRED: UserState.ValueType  # 3
"""User's registration has expired"""
USER_STATE_VERIFICATION_ERROR: UserState.ValueType  # 4
"""Error occurred during verification"""
Global___UserState: typing_extensions.TypeAlias = UserState

class _CompileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CompileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CompileType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FULL: _CompileType.ValueType  # 0
    """Full compile"""
    SPECULATIVE: _CompileType.ValueType  # 1
    """Speculative compile"""

class CompileType(_CompileType, metaclass=_CompileTypeEnumTypeWrapper):
    """Compile type enum"""

FULL: CompileType.ValueType  # 0
"""Full compile"""
SPECULATIVE: CompileType.ValueType  # 1
"""Speculative compile"""
Global___CompileType: typing_extensions.TypeAlias = CompileType

class _CompileCause:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CompileCauseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CompileCause.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMPILE_CAUSE_DID_SAVE: _CompileCause.ValueType  # 0
    """Compile was caused by a user saving a file"""
    COMPILE_CAUSE_COMPILE_LSP_COMMAND: _CompileCause.ValueType  # 1
    """Compile was caused by an expliict compile command sent to the LSP"""
    COMPILE_CAUSE_REFRESH_SOURCES: _CompileCause.ValueType  # 2
    """Compile was caused by a request to refresh sources for a project"""

class CompileCause(_CompileCause, metaclass=_CompileCauseEnumTypeWrapper): ...

COMPILE_CAUSE_DID_SAVE: CompileCause.ValueType  # 0
"""Compile was caused by a user saving a file"""
COMPILE_CAUSE_COMPILE_LSP_COMMAND: CompileCause.ValueType  # 1
"""Compile was caused by an expliict compile command sent to the LSP"""
COMPILE_CAUSE_REFRESH_SOURCES: CompileCause.ValueType  # 2
"""Compile was caused by a request to refresh sources for a project"""
Global___CompileCause: typing_extensions.TypeAlias = CompileCause

@typing.final
class User(google.protobuf.message.Message):
    """User information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALS_SOURCE_FIELD_NUMBER: builtins.int
    DBT_CLOUD_USER_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_HOSTNAME_FIELD_NUMBER: builtins.int
    REGISTRATION_STATE_FIELD_NUMBER: builtins.int
    credentials_source: builtins.str
    """source used to get credentials for the user (dbt_cloud.yml, web)"""
    dbt_cloud_user_id: builtins.str
    """dbt cloud user id, can be null if the user is not registered"""
    dbt_cloud_hostname: builtins.str
    """dbt cloud hostname, can be null if the user is not registered"""
    registration_state: builtins.str
    """registration state as reported by the vscode extension"""
    def __init__(
        self,
        *,
        credentials_source: builtins.str = ...,
        dbt_cloud_user_id: builtins.str = ...,
        dbt_cloud_hostname: builtins.str = ...,
        registration_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["credentials_source", b"credentials_source", "dbt_cloud_hostname", b"dbt_cloud_hostname", "dbt_cloud_user_id", b"dbt_cloud_user_id", "registration_state", b"registration_state"]) -> None: ...

Global___User: typing_extensions.TypeAlias = User

@typing.final
class Editor(google.protobuf.message.Message):
    """Editor and extension information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    MACHINE_ID_FIELD_NUMBER: builtins.int
    MAC_MACHINE_ID_FIELD_NUMBER: builtins.int
    EXTENSION_VERSION_FIELD_NUMBER: builtins.int
    EDITOR_NAME_FIELD_NUMBER: builtins.int
    EDITOR_VERSION_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """session id (reported by the editor)"""
    machine_id: builtins.str
    """machine id (reported by the editor)"""
    mac_machine_id: builtins.str
    """hashed mac address (reported by the editor)"""
    extension_version: builtins.str
    """version of the dbt extension"""
    editor_name: builtins.str
    """editor name (reported by the editor)"""
    editor_version: builtins.str
    """editor version (reported by the editor)"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        machine_id: builtins.str = ...,
        mac_machine_id: builtins.str = ...,
        extension_version: builtins.str = ...,
        editor_name: builtins.str = ...,
        editor_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["editor_name", b"editor_name", "editor_version", b"editor_version", "extension_version", b"extension_version", "mac_machine_id", b"mac_machine_id", "machine_id", b"machine_id", "session_id", b"session_id"]) -> None: ...

Global___Editor: typing_extensions.TypeAlias = Editor

@typing.final
class CompileError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """Error message"""
    code: builtins.int
    """Error codes: https://github.com/dbt-labs/fs/blob/main/fs/sa/crates/dbt-common/src/error/codes.rs"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "message", b"message"]) -> None: ...

Global___CompileError: typing_extensions.TypeAlias = CompileError



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExecutionPhase:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExecutionPhaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExecutionPhase.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXECUTION_PHASE_UNSPECIFIED: _ExecutionPhase.ValueType  # 0
    """Do not use."""
    EXECUTION_PHASE_CLEAN: _ExecutionPhase.ValueType  # 10
    """Build/run flow phases

    Cleaning output folders (e.g. the target directory)
    """
    EXECUTION_PHASE_LOAD_PROJECT: _ExecutionPhase.ValueType  # 20
    """dbt Project loading: analyzing dbt_project, profiles.yml and scanning files"""
    EXECUTION_PHASE_PARSE: _ExecutionPhase.ValueType  # 30
    """Parsing and macro name resolution of all dbt files"""
    EXECUTION_PHASE_SCHEDULE: _ExecutionPhase.ValueType  # 40
    """Schedule nodes based on selection criteria and dependencies."""
    EXECUTION_PHASE_COMPARE: _ExecutionPhase.ValueType  # 45
    """Run dbt-compare macros against selected nodes"""
    EXECUTION_PHASE_INIT_ADAPTER: _ExecutionPhase.ValueType  # 50
    """Initializing the adapter (warehouse connection and configuration)"""
    EXECUTION_PHASE_DEFER_HYDRATION: _ExecutionPhase.ValueType  # 60
    """Handling deferral. Fetching state source schemas from remote, hydrating relation, and schema cache"""
    EXECUTION_PHASE_TASK_GRAPH_BUILD: _ExecutionPhase.ValueType  # 70
    """Building the task graph from the schedule"""
    EXECUTION_PHASE_NODE_CACHE_HYDRATION: _ExecutionPhase.ValueType  # 80
    """Hydration of cached models, seeds, snapshots and sources"""
    EXECUTION_PHASE_RENDER: _ExecutionPhase.ValueType  # 90
    """Render SQL (also called `compile` in dbt core)"""
    EXECUTION_PHASE_ANALYZE: _ExecutionPhase.ValueType  # 100
    """SQL static analysis"""
    EXECUTION_PHASE_RUN: _ExecutionPhase.ValueType  # 110
    """Execution against the target database"""
    EXECUTION_PHASE_FRESHNESS_ANALYSIS: _ExecutionPhase.ValueType  # 120
    """Phases for other commands

    Freshness analysis of sources and models
    """
    EXECUTION_PHASE_LINEAGE: _ExecutionPhase.ValueType  # 130
    """Analysis of individual node lineages"""
    EXECUTION_PHASE_DEBUG: _ExecutionPhase.ValueType  # 140
    """Debugging connection correctness and availability to the warehouse"""

class ExecutionPhase(_ExecutionPhase, metaclass=_ExecutionPhaseEnumTypeWrapper):
    """A superset of all possible phases across all dbt commands.
    Note that not all phases are relevant to all commands.
    """

EXECUTION_PHASE_UNSPECIFIED: ExecutionPhase.ValueType  # 0
"""Do not use."""
EXECUTION_PHASE_CLEAN: ExecutionPhase.ValueType  # 10
"""Build/run flow phases

Cleaning output folders (e.g. the target directory)
"""
EXECUTION_PHASE_LOAD_PROJECT: ExecutionPhase.ValueType  # 20
"""dbt Project loading: analyzing dbt_project, profiles.yml and scanning files"""
EXECUTION_PHASE_PARSE: ExecutionPhase.ValueType  # 30
"""Parsing and macro name resolution of all dbt files"""
EXECUTION_PHASE_SCHEDULE: ExecutionPhase.ValueType  # 40
"""Schedule nodes based on selection criteria and dependencies."""
EXECUTION_PHASE_COMPARE: ExecutionPhase.ValueType  # 45
"""Run dbt-compare macros against selected nodes"""
EXECUTION_PHASE_INIT_ADAPTER: ExecutionPhase.ValueType  # 50
"""Initializing the adapter (warehouse connection and configuration)"""
EXECUTION_PHASE_DEFER_HYDRATION: ExecutionPhase.ValueType  # 60
"""Handling deferral. Fetching state source schemas from remote, hydrating relation, and schema cache"""
EXECUTION_PHASE_TASK_GRAPH_BUILD: ExecutionPhase.ValueType  # 70
"""Building the task graph from the schedule"""
EXECUTION_PHASE_NODE_CACHE_HYDRATION: ExecutionPhase.ValueType  # 80
"""Hydration of cached models, seeds, snapshots and sources"""
EXECUTION_PHASE_RENDER: ExecutionPhase.ValueType  # 90
"""Render SQL (also called `compile` in dbt core)"""
EXECUTION_PHASE_ANALYZE: ExecutionPhase.ValueType  # 100
"""SQL static analysis"""
EXECUTION_PHASE_RUN: ExecutionPhase.ValueType  # 110
"""Execution against the target database"""
EXECUTION_PHASE_FRESHNESS_ANALYSIS: ExecutionPhase.ValueType  # 120
"""Phases for other commands

Freshness analysis of sources and models
"""
EXECUTION_PHASE_LINEAGE: ExecutionPhase.ValueType  # 130
"""Analysis of individual node lineages"""
EXECUTION_PHASE_DEBUG: ExecutionPhase.ValueType  # 140
"""Debugging connection correctness and availability to the warehouse"""
Global___ExecutionPhase: typing_extensions.TypeAlias = ExecutionPhase

@typing.final
class PhaseExecuted(google.protobuf.message.Message):
    """Top-level event for reporting a build phase, with optional details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHASE_FIELD_NUMBER: builtins.int
    NODE_COUNT_TOTAL_FIELD_NUMBER: builtins.int
    NODE_COUNT_SKIPPED_FIELD_NUMBER: builtins.int
    NODE_COUNT_ERROR_FIELD_NUMBER: builtins.int
    phase: Global___ExecutionPhase.ValueType
    """The current phase of execution."""
    node_count_total: builtins.int
    """Optional count of total individual nodes within the phase (when applicable)."""
    node_count_skipped: builtins.int
    """Optional count of skipped nodes within the phase (when applicable).
    Skipped means `node_outcome` was set to `NODE_OUTCOME_SKIPPED`.
    """
    node_count_error: builtins.int
    """Optional count of errored nodes within the phase (when applicable).
    Error means `node_outcome` was set to `NODE_OUTCOME_ERROR`.
    """
    def __init__(
        self,
        *,
        phase: Global___ExecutionPhase.ValueType = ...,
        node_count_total: builtins.int | None = ...,
        node_count_skipped: builtins.int | None = ...,
        node_count_error: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_node_count_error", b"_node_count_error", "_node_count_skipped", b"_node_count_skipped", "_node_count_total", b"_node_count_total", "node_count_error", b"node_count_error", "node_count_skipped", b"node_count_skipped", "node_count_total", b"node_count_total"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_node_count_error", b"_node_count_error", "_node_count_skipped", b"_node_count_skipped", "_node_count_total", b"_node_count_total", "node_count_error", b"node_count_error", "node_count_skipped", b"node_count_skipped", "node_count_total", b"node_count_total", "phase", b"phase"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_node_count_error", b"_node_count_error"]) -> typing.Literal["node_count_error"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_node_count_skipped", b"_node_count_skipped"]) -> typing.Literal["node_count_skipped"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_node_count_total", b"_node_count_total"]) -> typing.Literal["node_count_total"] | None: ...

Global___PhaseExecuted: typing_extensions.TypeAlias = PhaseExecuted



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompiledCodeInline(google.protobuf.message.Message):
    """Log event that carries inline compiled SQL code."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_FIELD_NUMBER: builtins.int
    sql: builtins.str
    def __init__(
        self,
        *,
        sql: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sql", b"sql"]) -> None: ...

Global___CompiledCodeInline: typing_extensions.TypeAlias = CompiledCodeInline



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class VortexTelemetryDbtCloudContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    FEATURE_FIELD_NUMBER: builtins.int
    SNOWPLOW_DOMAIN_SESSION_ID_FIELD_NUMBER: builtins.int
    SNOWPLOW_DOMAIN_USER_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    REFERRER_URL_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ACCOUNT_IDENTIFIER_FIELD_NUMBER: builtins.int
    DBT_CLOUD_PROJECT_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_USER_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    feature: builtins.str
    """feature/product name emitting the telemetry event"""
    snowplow_domain_session_id: builtins.str
    """The snowplow domain session ID. This can be used to join these events with snowplow events."""
    snowplow_domain_user_id: builtins.str
    """The snowplow domain user ID. This can be used to join these events with snowplow events."""
    session_id: builtins.str
    """A session ID that can be used to correlate events that were emmitted by the same
    user during the same session.
    """
    referrer_url: builtins.str
    """The URL of the page the user was on when telemetry event was sent"""
    dbt_cloud_account_id: builtins.str
    """dbt Cloud account ID"""
    dbt_cloud_account_identifier: builtins.str
    """dbt Cloud account identifier"""
    dbt_cloud_project_id: builtins.str
    """dbt Cloud project ID"""
    dbt_cloud_environment_id: builtins.str
    """dbt Cloud environment ID"""
    dbt_cloud_user_id: builtins.str
    """dbt Cloud user ID"""
    def __init__(
        self,
        *,
        event_id: builtins.str = ...,
        feature: builtins.str = ...,
        snowplow_domain_session_id: builtins.str = ...,
        snowplow_domain_user_id: builtins.str = ...,
        session_id: builtins.str = ...,
        referrer_url: builtins.str = ...,
        dbt_cloud_account_id: builtins.str = ...,
        dbt_cloud_account_identifier: builtins.str = ...,
        dbt_cloud_project_id: builtins.str = ...,
        dbt_cloud_environment_id: builtins.str = ...,
        dbt_cloud_user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dbt_cloud_account_id", b"dbt_cloud_account_id", "dbt_cloud_account_identifier", b"dbt_cloud_account_identifier", "dbt_cloud_environment_id", b"dbt_cloud_environment_id", "dbt_cloud_project_id", b"dbt_cloud_project_id", "dbt_cloud_user_id", b"dbt_cloud_user_id", "event_id", b"event_id", "feature", b"feature", "referrer_url", b"referrer_url", "session_id", b"session_id", "snowplow_domain_session_id", b"snowplow_domain_session_id", "snowplow_domain_user_id", b"snowplow_domain_user_id"]) -> None: ...

Global___VortexTelemetryDbtCloudContext: typing_extensions.TypeAlias = VortexTelemetryDbtCloudContext



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/node/node.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dbtlabs/proto/public/v1/events/fusion/node/node.proto\x12\x1cv1.public.events.fusion.node\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\x95\x01\n\x14TestEvaluationDetail\x12?\n\x0ctest_outcome\x18\x01 \x01(\x0e\x32).v1.public.events.fusion.node.TestOutcome\x12\x14\n\x0c\x66\x61iling_rows\x18\x02 \x01(\x05\x12\x17\n\ndiff_table\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_diff_table\"m\n\x15SourceFreshnessDetail\x12T\n\x16node_freshness_outcome\x18\x01 \x01(\x0e\x32\x34.v1.public.events.fusion.node.SourceFreshnessOutcome\"[\n\x0fNodeCacheDetail\x12H\n\x11node_cache_reason\x18\x01 \x01(\x0e\x32-.v1.public.events.fusion.node.NodeCacheReason\"4\n\x16NodeSkipUpstreamDetail\x12\x1a\n\x12upstream_unique_id\x18\x01 \x01(\t\"\xc3\t\n\rNodeEvaluated\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06schema\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nidentifier\x18\x05 \x01(\tH\x03\x88\x01\x01\x12O\n\x0fmaterialization\x18\x07 \x01(\x0e\x32\x31.v1.public.events.fusion.node.NodeMaterializationH\x04\x88\x01\x01\x12#\n\x16\x63ustom_materialization\x18\x08 \x01(\tH\x05\x88\x01\x01\x12\x39\n\tnode_type\x18\t \x01(\x0e\x32&.v1.public.events.fusion.node.NodeType\x12?\n\x0cnode_outcome\x18\n \x01(\x0e\x32).v1.public.events.fusion.node.NodeOutcome\x12<\n\x05phase\x18\x0b \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhase\x12I\n\x0fnode_error_type\x18\x14 \x01(\x0e\x32+.v1.public.events.fusion.node.NodeErrorTypeH\x06\x88\x01\x01\x12O\n\x12node_cancel_reason\x18\x15 \x01(\x0e\x32..v1.public.events.fusion.node.NodeCancelReasonH\x07\x88\x01\x01\x12K\n\x10node_skip_reason\x18\x16 \x01(\x0e\x32,.v1.public.events.fusion.node.NodeSkipReasonH\x08\x88\x01\x01\x12J\n\x11node_cache_detail\x18\x1e \x01(\x0b\x32-.v1.public.events.fusion.node.NodeCacheDetailH\x00\x12N\n\x10node_test_detail\x18\x1f \x01(\x0b\x32\x32.v1.public.events.fusion.node.TestEvaluationDetailH\x00\x12U\n\x16node_freshness_outcome\x18  \x01(\x0b\x32\x33.v1.public.events.fusion.node.SourceFreshnessDetailH\x00\x12Y\n\x19node_skip_upstream_detail\x18! \x01(\x0b\x32\x34.v1.public.events.fusion.node.NodeSkipUpstreamDetailH\x00\x12 \n\x13\x64\x62t_core_event_code\x18( \x01(\tH\t\x88\x01\x01\x42\x15\n\x13node_outcome_detailB\x0b\n\t_databaseB\t\n\x07_schemaB\r\n\x0b_identifierB\x12\n\x10_materializationB\x19\n\x17_custom_materializationB\x12\n\x10_node_error_typeB\x15\n\x13_node_cancel_reasonB\x13\n\x11_node_skip_reasonB\x16\n\x14_dbt_core_event_code*\x88\x03\n\x08NodeType\x12\x19\n\x15NODE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fNODE_TYPE_MODEL\x10\x01\x12\x12\n\x0eNODE_TYPE_SEED\x10\x02\x12\x16\n\x12NODE_TYPE_SNAPSHOT\x10\x0b\x12\x14\n\x10NODE_TYPE_SOURCE\x10\x03\x12\x12\n\x0eNODE_TYPE_TEST\x10\x04\x12\x17\n\x13NODE_TYPE_UNIT_TEST\x10\x05\x12\x13\n\x0fNODE_TYPE_MACRO\x10\x06\x12\x18\n\x14NODE_TYPE_DOCS_MACRO\x10\x07\x12\x16\n\x12NODE_TYPE_ANALYSIS\x10\x08\x12\x17\n\x13NODE_TYPE_OPERATION\x10\t\x12\x16\n\x12NODE_TYPE_EXPOSURE\x10\n\x12\x14\n\x10NODE_TYPE_METRIC\x10\x0c\x12\x19\n\x15NODE_TYPE_SAVED_QUERY\x10\r\x12\x1c\n\x18NODE_TYPE_SEMANTIC_MODEL\x10\x0e\x12\x16\n\x12NODE_TYPE_FUNCTION\x10\x0f*\x92\x01\n\x0bNodeOutcome\x12\x1c\n\x18NODE_OUTCOME_UNSPECIFIED\x10\x00\x12\x18\n\x14NODE_OUTCOME_SUCCESS\x10\x01\x12\x16\n\x12NODE_OUTCOME_ERROR\x10\x02\x12\x19\n\x15NODE_OUTCOME_CANCELED\x10\x03\x12\x18\n\x14NODE_OUTCOME_SKIPPED\x10\x04*e\n\rNodeErrorType\x12\x1c\n\x18NODE_ERROR_TYPE_INTERNAL\x10\x00\x12\x1c\n\x18NODE_ERROR_TYPE_EXTERNAL\x10\x01\x12\x18\n\x14NODE_ERROR_TYPE_USER\x10\x02*9\n\x10NodeCancelReason\x12%\n!NODE_CANCEL_REASON_USER_CANCELLED\x10\x00*\xd3\x01\n\x0eNodeSkipReason\x12 \n\x1cNODE_SKIP_REASON_UNSPECIFIED\x10\x00\x12\x1d\n\x19NODE_SKIP_REASON_UPSTREAM\x10\x01\x12\x1b\n\x17NODE_SKIP_REASON_CACHED\x10\x02\x12#\n\x1fNODE_SKIP_REASON_PHASE_DISABLED\x10\x03\x12\x1a\n\x16NODE_SKIP_REASON_NO_OP\x10\x04\x12\"\n\x1eNODE_SKIP_REASON_PHASE_SKIPPED\x10\x05*\x85\x01\n\x0fNodeCacheReason\x12 \n\x1cNODE_CACHE_REASON_NO_CHANGES\x10\x00\x12!\n\x1dNODE_CACHE_REASON_STILL_FRESH\x10\x01\x12-\n)NODE_CACHE_REASON_UPDATE_CRITERIA_NOT_MET\x10\x02*\xc8\x04\n\x13NodeMaterialization\x12 \n\x1cNODE_MATERIALIZATION_UNKNOWN\x10\x00\x12!\n\x1dNODE_MATERIALIZATION_SNAPSHOT\x10\x01\x12\x1d\n\x19NODE_MATERIALIZATION_SEED\x10\x02\x12\x1d\n\x19NODE_MATERIALIZATION_VIEW\x10\x03\x12\x1e\n\x1aNODE_MATERIALIZATION_TABLE\x10\x04\x12$\n NODE_MATERIALIZATION_INCREMENTAL\x10\x05\x12*\n&NODE_MATERIALIZATION_MATERIALIZED_VIEW\x10\x06\x12!\n\x1dNODE_MATERIALIZATION_EXTERNAL\x10\x07\x12\x1d\n\x19NODE_MATERIALIZATION_TEST\x10\x08\x12\"\n\x1eNODE_MATERIALIZATION_EPHEMERAL\x10\t\x12\x1d\n\x19NODE_MATERIALIZATION_UNIT\x10\n\x12!\n\x1dNODE_MATERIALIZATION_ANALYSIS\x10\x0b\x12(\n$NODE_MATERIALIZATION_STREAMING_TABLE\x10\x0c\x12&\n\"NODE_MATERIALIZATION_DYNAMIC_TABLE\x10\r\x12!\n\x1dNODE_MATERIALIZATION_FUNCTION\x10\x0e\x12\x1f\n\x1bNODE_MATERIALIZATION_CUSTOM\x10\x64*X\n\x0bTestOutcome\x12\x17\n\x13TEST_OUTCOME_PASSED\x10\x00\x12\x17\n\x13TEST_OUTCOME_WARNED\x10\x01\x12\x17\n\x13TEST_OUTCOME_FAILED\x10\x02*\x9f\x01\n\x16SourceFreshnessOutcome\x12+\n\'SOURCE_FRESHNESS_OUTCOME_OUTCOME_PASSED\x10\x00\x12+\n\'SOURCE_FRESHNESS_OUTCOME_OUTCOME_WARNED\x10\x01\x12+\n\'SOURCE_FRESHNESS_OUTCOME_OUTCOME_FAILED\x10\x02\x42?Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.node.node_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/node'
  _globals['_NODETYPE']._serialized_start=1777
  _globals['_NODETYPE']._serialized_end=2169
  _globals['_NODEOUTCOME']._serialized_start=2172
  _globals['_NODEOUTCOME']._serialized_end=2318
  _globals['_NODEERRORTYPE']._serialized_start=2320
  _globals['_NODEERRORTYPE']._serialized_end=2421
  _globals['_NODECANCELREASON']._serialized_start=2423
  _globals['_NODECANCELREASON']._serialized_end=2480
  _globals['_NODESKIPREASON']._serialized_start=2483
  _globals['_NODESKIPREASON']._serialized_end=2694
  _globals['_NODECACHEREASON']._serialized_start=2697
  _globals['_NODECACHEREASON']._serialized_end=2830
  _globals['_NODEMATERIALIZATION']._serialized_start=2833
  _globals['_NODEMATERIALIZATION']._serialized_end=3417
  _globals['_TESTOUTCOME']._serialized_start=3419
  _globals['_TESTOUTCOME']._serialized_end=3507
  _globals['_SOURCEFRESHNESSOUTCOME']._serialized_start=3510
  _globals['_SOURCEFRESHNESSOUTCOME']._serialized_end=3669
  _globals['_TESTEVALUATIONDETAIL']._serialized_start=145
  _globals['_TESTEVALUATIONDETAIL']._serialized_end=294
  _globals['_SOURCEFRESHNESSDETAIL']._serialized_start=296
  _globals['_SOURCEFRESHNESSDETAIL']._serialized_end=405
  _globals['_NODECACHEDETAIL']._serialized_start=407
  _globals['_NODECACHEDETAIL']._serialized_end=498
  _globals['_NODESKIPUPSTREAMDETAIL']._serialized_start=500
  _globals['_NODESKIPUPSTREAMDETAIL']._serialized_end=552
  _globals['_NODEEVALUATED']._serialized_start=555
  _globals['_NODEEVALUATED']._serialized_end=1774
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AdapterCommonEventInfo(google.protobuf.message.Message):
    """Common event info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    code: builtins.str
    msg: builtins.str
    level: builtins.str
    invocation_id: builtins.str
    pid: builtins.int
    thread: builtins.str
    category: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
        level: builtins.str = ...,
        invocation_id: builtins.str = ...,
        pid: builtins.int = ...,
        thread: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        category: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "code", b"code", "extra", b"extra", "invocation_id", b"invocation_id", "level", b"level", "msg", b"msg", "name", b"name", "pid", b"pid", "thread", b"thread", "ts", b"ts"]) -> None: ...

Global___AdapterCommonEventInfo: typing_extensions.TypeAlias = AdapterCommonEventInfo

@typing.final
class AdapterNodeRelation(google.protobuf.message.Message):
    """AdapterNodeRelation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    ALIAS_FIELD_NUMBER: builtins.int
    RELATION_NAME_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    alias: builtins.str
    relation_name: builtins.str
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        alias: builtins.str = ...,
        relation_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "database", b"database", "relation_name", b"relation_name", "schema", b"schema"]) -> None: ...

Global___AdapterNodeRelation: typing_extensions.TypeAlias = AdapterNodeRelation

@typing.final
class AdapterNodeInfo(google.protobuf.message.Message):
    """NodeInfo"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_PATH_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    MATERIALIZED_FIELD_NUMBER: builtins.int
    NODE_STATUS_FIELD_NUMBER: builtins.int
    NODE_STARTED_AT_FIELD_NUMBER: builtins.int
    NODE_FINISHED_AT_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    NODE_RELATION_FIELD_NUMBER: builtins.int
    NODE_CHECKSUM_FIELD_NUMBER: builtins.int
    node_path: builtins.str
    node_name: builtins.str
    unique_id: builtins.str
    resource_type: builtins.str
    materialized: builtins.str
    node_status: builtins.str
    node_started_at: builtins.str
    node_finished_at: builtins.str
    node_checksum: builtins.str
    @property
    def meta(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def node_relation(self) -> Global___AdapterNodeRelation: ...
    def __init__(
        self,
        *,
        node_path: builtins.str = ...,
        node_name: builtins.str = ...,
        unique_id: builtins.str = ...,
        resource_type: builtins.str = ...,
        materialized: builtins.str = ...,
        node_status: builtins.str = ...,
        node_started_at: builtins.str = ...,
        node_finished_at: builtins.str = ...,
        meta: google.protobuf.struct_pb2.Struct | None = ...,
        node_relation: Global___AdapterNodeRelation | None = ...,
        node_checksum: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta", "node_relation", b"node_relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["materialized", b"materialized", "meta", b"meta", "node_checksum", b"node_checksum", "node_finished_at", b"node_finished_at", "node_name", b"node_name", "node_path", b"node_path", "node_relation", b"node_relation", "node_started_at", b"node_started_at", "node_status", b"node_status", "resource_type", b"resource_type", "unique_id", b"unique_id"]) -> None: ...

Global___AdapterNodeInfo: typing_extensions.TypeAlias = AdapterNodeInfo

@typing.final
class ReferenceKeyMsg(google.protobuf.message.Message):
    """ReferenceKey"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    IDENTIFIER_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    identifier: builtins.str
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "identifier", b"identifier", "schema", b"schema"]) -> None: ...

Global___ReferenceKeyMsg: typing_extensions.TypeAlias = ReferenceKeyMsg

@typing.final
class AdapterDeprecationWarning(google.protobuf.message.Message):
    """D - Deprecations

    D005
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    old_name: builtins.str
    new_name: builtins.str
    def __init__(
        self,
        *,
        old_name: builtins.str = ...,
        new_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "old_name", b"old_name"]) -> None: ...

Global___AdapterDeprecationWarning: typing_extensions.TypeAlias = AdapterDeprecationWarning

@typing.final
class AdapterDeprecationWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterDeprecationWarning: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterDeprecationWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterDeprecationWarningMsg: typing_extensions.TypeAlias = AdapterDeprecationWarningMsg

@typing.final
class CollectFreshnessReturnSignature(google.protobuf.message.Message):
    """D012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CollectFreshnessReturnSignature: typing_extensions.TypeAlias = CollectFreshnessReturnSignature

@typing.final
class CollectFreshnessReturnSignatureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CollectFreshnessReturnSignature: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CollectFreshnessReturnSignature | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CollectFreshnessReturnSignatureMsg: typing_extensions.TypeAlias = CollectFreshnessReturnSignatureMsg

@typing.final
class AdapterEventDebug(google.protobuf.message.Message):
    """E - DB Adapter

    E001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventDebug: typing_extensions.TypeAlias = AdapterEventDebug

@typing.final
class AdapterEventDebugMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventDebug: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventDebug | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventDebugMsg: typing_extensions.TypeAlias = AdapterEventDebugMsg

@typing.final
class AdapterEventInfo(google.protobuf.message.Message):
    """E002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventInfo: typing_extensions.TypeAlias = AdapterEventInfo

@typing.final
class AdapterEventInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventInfo: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventInfoMsg: typing_extensions.TypeAlias = AdapterEventInfoMsg

@typing.final
class AdapterEventWarning(google.protobuf.message.Message):
    """E003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventWarning: typing_extensions.TypeAlias = AdapterEventWarning

@typing.final
class AdapterEventWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventWarning: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventWarningMsg: typing_extensions.TypeAlias = AdapterEventWarningMsg

@typing.final
class AdapterEventError(google.protobuf.message.Message):
    """E004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "exc_info", b"exc_info", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventError: typing_extensions.TypeAlias = AdapterEventError

@typing.final
class AdapterEventErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventErrorMsg: typing_extensions.TypeAlias = AdapterEventErrorMsg

@typing.final
class NewConnection(google.protobuf.message.Message):
    """E005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_TYPE_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_type: builtins.str
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_type: builtins.str = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "conn_type", b"conn_type", "node_info", b"node_info"]) -> None: ...

Global___NewConnection: typing_extensions.TypeAlias = NewConnection

@typing.final
class NewConnectionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___NewConnection: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___NewConnection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NewConnectionMsg: typing_extensions.TypeAlias = NewConnectionMsg

@typing.final
class ConnectionReused(google.protobuf.message.Message):
    """E006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    ORIG_CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    orig_conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
        orig_conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "orig_conn_name", b"orig_conn_name"]) -> None: ...

Global___ConnectionReused: typing_extensions.TypeAlias = ConnectionReused

@typing.final
class ConnectionReusedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionReused: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionReused | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionReusedMsg: typing_extensions.TypeAlias = ConnectionReusedMsg

@typing.final
class ConnectionLeftOpenInCleanup(google.protobuf.message.Message):
    """E007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name"]) -> None: ...

Global___ConnectionLeftOpenInCleanup: typing_extensions.TypeAlias = ConnectionLeftOpenInCleanup

@typing.final
class ConnectionLeftOpenInCleanupMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionLeftOpenInCleanup: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionLeftOpenInCleanup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionLeftOpenInCleanupMsg: typing_extensions.TypeAlias = ConnectionLeftOpenInCleanupMsg

@typing.final
class ConnectionClosedInCleanup(google.protobuf.message.Message):
    """E008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name"]) -> None: ...

Global___ConnectionClosedInCleanup: typing_extensions.TypeAlias = ConnectionClosedInCleanup

@typing.final
class ConnectionClosedInCleanupMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionClosedInCleanup: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionClosedInCleanup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionClosedInCleanupMsg: typing_extensions.TypeAlias = ConnectionClosedInCleanupMsg

@typing.final
class RollbackFailed(google.protobuf.message.Message):
    """E009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "exc_info", b"exc_info", "node_info", b"node_info"]) -> None: ...

Global___RollbackFailed: typing_extensions.TypeAlias = RollbackFailed

@typing.final
class RollbackFailedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___RollbackFailed: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___RollbackFailed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RollbackFailedMsg: typing_extensions.TypeAlias = RollbackFailedMsg

@typing.final
class ConnectionClosed(google.protobuf.message.Message):
    """E010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___ConnectionClosed: typing_extensions.TypeAlias = ConnectionClosed

@typing.final
class ConnectionClosedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionClosed: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionClosed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionClosedMsg: typing_extensions.TypeAlias = ConnectionClosedMsg

@typing.final
class ConnectionLeftOpen(google.protobuf.message.Message):
    """E011"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___ConnectionLeftOpen: typing_extensions.TypeAlias = ConnectionLeftOpen

@typing.final
class ConnectionLeftOpenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionLeftOpen: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionLeftOpen | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionLeftOpenMsg: typing_extensions.TypeAlias = ConnectionLeftOpenMsg

@typing.final
class Rollback(google.protobuf.message.Message):
    """E012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___Rollback: typing_extensions.TypeAlias = Rollback

@typing.final
class RollbackMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___Rollback: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___Rollback | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RollbackMsg: typing_extensions.TypeAlias = RollbackMsg

@typing.final
class CacheMiss(google.protobuf.message.Message):
    """E013"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    database: builtins.str
    schema: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
        database: builtins.str = ...,
        schema: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "database", b"database", "schema", b"schema"]) -> None: ...

Global___CacheMiss: typing_extensions.TypeAlias = CacheMiss

@typing.final
class CacheMissMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CacheMiss: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CacheMiss | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CacheMissMsg: typing_extensions.TypeAlias = CacheMissMsg

@typing.final
class ListRelations(google.protobuf.message.Message):
    """E014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    RELATIONS_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    @property
    def relations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ReferenceKeyMsg]: ...
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        relations: collections.abc.Iterable[Global___ReferenceKeyMsg] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "relations", b"relations", "schema", b"schema"]) -> None: ...

Global___ListRelations: typing_extensions.TypeAlias = ListRelations

@typing.final
class ListRelationsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ListRelations: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ListRelations | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ListRelationsMsg: typing_extensions.TypeAlias = ListRelationsMsg

@typing.final
class ConnectionUsed(google.protobuf.message.Message):
    """E015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_TYPE_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_type: builtins.str
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_type: builtins.str = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "conn_type", b"conn_type", "node_info", b"node_info"]) -> None: ...

Global___ConnectionUsed: typing_extensions.TypeAlias = ConnectionUsed

@typing.final
class ConnectionUsedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionUsed: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionUsed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionUsedMsg: typing_extensions.TypeAlias = ConnectionUsedMsg

@typing.final
class SQLQuery(google.protobuf.message.Message):
    """E016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    sql: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
        sql: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info", "sql", b"sql"]) -> None: ...

Global___SQLQuery: typing_extensions.TypeAlias = SQLQuery

@typing.final
class SQLQueryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SQLQuery: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SQLQuery | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLQueryMsg: typing_extensions.TypeAlias = SQLQueryMsg

@typing.final
class SQLQueryStatus(google.protobuf.message.Message):
    """E017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ELAPSED_FIELD_NUMBER: builtins.int
    QUERY_ID_FIELD_NUMBER: builtins.int
    status: builtins.str
    elapsed: builtins.float
    query_id: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        status: builtins.str = ...,
        elapsed: builtins.float = ...,
        query_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["elapsed", b"elapsed", "node_info", b"node_info", "query_id", b"query_id", "status", b"status"]) -> None: ...

Global___SQLQueryStatus: typing_extensions.TypeAlias = SQLQueryStatus

@typing.final
class SQLQueryStatusMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SQLQueryStatus: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SQLQueryStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLQueryStatusMsg: typing_extensions.TypeAlias = SQLQueryStatusMsg

@typing.final
class SQLCommit(google.protobuf.message.Message):
    """E018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___SQLCommit: typing_extensions.TypeAlias = SQLCommit

@typing.final
class SQLCommitMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SQLCommit: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SQLCommit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLCommitMsg: typing_extensions.TypeAlias = SQLCommitMsg

@typing.final
class ColTypeChange(google.protobuf.message.Message):
    """E019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIG_TYPE_FIELD_NUMBER: builtins.int
    NEW_TYPE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    orig_type: builtins.str
    new_type: builtins.str
    @property
    def table(self) -> Global___ReferenceKeyMsg: ...
    def __init__(
        self,
        *,
        orig_type: builtins.str = ...,
        new_type: builtins.str = ...,
        table: Global___ReferenceKeyMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_type", b"new_type", "orig_type", b"orig_type", "table", b"table"]) -> None: ...

Global___ColTypeChange: typing_extensions.TypeAlias = ColTypeChange

@typing.final
class ColTypeChangeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ColTypeChange: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ColTypeChange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ColTypeChangeMsg: typing_extensions.TypeAlias = ColTypeChangeMsg

@typing.final
class SchemaCreation(google.protobuf.message.Message):
    """E020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_FIELD_NUMBER: builtins.int
    @property
    def relation(self) -> Global___ReferenceKeyMsg: ...
    def __init__(
        self,
        *,
        relation: Global___ReferenceKeyMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["relation", b"relation"]) -> None: ...

Global___SchemaCreation: typing_extensions.TypeAlias = SchemaCreation

@typing.final
class SchemaCreationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SchemaCreation: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SchemaCreation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SchemaCreationMsg: typing_extensions.TypeAlias = SchemaCreationMsg

@typing.final
class SchemaDrop(google.protobuf.message.Message):
    """E021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_FIELD_NUMBER: builtins.int
    @property
    def relation(self) -> Global___ReferenceKeyMsg: ...
    def __init__(
        self,
        *,
        relation: Global___ReferenceKeyMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["relation", b"relation"]) -> None: ...

Global___SchemaDrop: typing_extensions.TypeAlias = SchemaDrop

@typing.final
class SchemaDropMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SchemaDrop: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SchemaDrop | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SchemaDropMsg: typing_extensions.TypeAlias = SchemaDropMsg

@typing.final
class CacheAction(google.protobuf.message.Message):
    """E022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    REF_KEY_FIELD_NUMBER: builtins.int
    REF_KEY_2_FIELD_NUMBER: builtins.int
    REF_KEY_3_FIELD_NUMBER: builtins.int
    REF_LIST_FIELD_NUMBER: builtins.int
    action: builtins.str
    @property
    def ref_key(self) -> Global___ReferenceKeyMsg: ...
    @property
    def ref_key_2(self) -> Global___ReferenceKeyMsg: ...
    @property
    def ref_key_3(self) -> Global___ReferenceKeyMsg: ...
    @property
    def ref_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ReferenceKeyMsg]: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        ref_key: Global___ReferenceKeyMsg | None = ...,
        ref_key_2: Global___ReferenceKeyMsg | None = ...,
        ref_key_3: Global___ReferenceKeyMsg | None = ...,
        ref_list: collections.abc.Iterable[Global___ReferenceKeyMsg] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ref_key", b"ref_key", "ref_key_2", b"ref_key_2", "ref_key_3", b"ref_key_3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "ref_key", b"ref_key", "ref_key_2", b"ref_key_2", "ref_key_3", b"ref_key_3", "ref_list", b"ref_list"]) -> None: ...

Global___CacheAction: typing_extensions.TypeAlias = CacheAction

@typing.final
class CacheActionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CacheAction: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CacheAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CacheActionMsg: typing_extensions.TypeAlias = CacheActionMsg

@typing.final
class CacheDumpGraph(google.protobuf.message.Message):
    """Skipping E023, E024, E025, E026, E027, E028, E029, E0230

    E031
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DumpEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DUMP_FIELD_NUMBER: builtins.int
    BEFORE_AFTER_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    before_after: builtins.str
    action: builtins.str
    @property
    def dump(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        dump: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        before_after: builtins.str = ...,
        action: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "before_after", b"before_after", "dump", b"dump"]) -> None: ...

Global___CacheDumpGraph: typing_extensions.TypeAlias = CacheDumpGraph

@typing.final
class CacheDumpGraphMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CacheDumpGraph: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CacheDumpGraph | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CacheDumpGraphMsg: typing_extensions.TypeAlias = CacheDumpGraphMsg

@typing.final
class AdapterRegistered(google.protobuf.message.Message):
    """Skipping E032, E033, E034

    E034
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTER_NAME_FIELD_NUMBER: builtins.int
    ADAPTER_VERSION_FIELD_NUMBER: builtins.int
    adapter_name: builtins.str
    adapter_version: builtins.str
    def __init__(
        self,
        *,
        adapter_name: builtins.str = ...,
        adapter_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter_name", b"adapter_name", "adapter_version", b"adapter_version"]) -> None: ...

Global___AdapterRegistered: typing_extensions.TypeAlias = AdapterRegistered

@typing.final
class AdapterRegisteredMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterRegistered: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterRegistered | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterRegisteredMsg: typing_extensions.TypeAlias = AdapterRegisteredMsg

@typing.final
class AdapterImportError(google.protobuf.message.Message):
    """E035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___AdapterImportError: typing_extensions.TypeAlias = AdapterImportError

@typing.final
class AdapterImportErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterImportError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterImportError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterImportErrorMsg: typing_extensions.TypeAlias = AdapterImportErrorMsg

@typing.final
class PluginLoadError(google.protobuf.message.Message):
    """E036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_INFO_FIELD_NUMBER: builtins.int
    exc_info: builtins.str
    def __init__(
        self,
        *,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

Global___PluginLoadError: typing_extensions.TypeAlias = PluginLoadError

@typing.final
class PluginLoadErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___PluginLoadError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___PluginLoadError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PluginLoadErrorMsg: typing_extensions.TypeAlias = PluginLoadErrorMsg

@typing.final
class NewConnectionOpening(google.protobuf.message.Message):
    """E037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONNECTION_STATE_FIELD_NUMBER: builtins.int
    connection_state: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        connection_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_state", b"connection_state", "node_info", b"node_info"]) -> None: ...

Global___NewConnectionOpening: typing_extensions.TypeAlias = NewConnectionOpening

@typing.final
class NewConnectionOpeningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___NewConnectionOpening: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___NewConnectionOpening | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NewConnectionOpeningMsg: typing_extensions.TypeAlias = NewConnectionOpeningMsg

@typing.final
class CodeExecution(google.protobuf.message.Message):
    """E038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    CODE_CONTENT_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    code_content: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
        code_content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code_content", b"code_content", "conn_name", b"conn_name"]) -> None: ...

Global___CodeExecution: typing_extensions.TypeAlias = CodeExecution

@typing.final
class CodeExecutionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CodeExecution: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CodeExecution | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CodeExecutionMsg: typing_extensions.TypeAlias = CodeExecutionMsg

@typing.final
class CodeExecutionStatus(google.protobuf.message.Message):
    """E039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    ELAPSED_FIELD_NUMBER: builtins.int
    status: builtins.str
    elapsed: builtins.float
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        elapsed: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["elapsed", b"elapsed", "status", b"status"]) -> None: ...

Global___CodeExecutionStatus: typing_extensions.TypeAlias = CodeExecutionStatus

@typing.final
class CodeExecutionStatusMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CodeExecutionStatus: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CodeExecutionStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CodeExecutionStatusMsg: typing_extensions.TypeAlias = CodeExecutionStatusMsg

@typing.final
class CatalogGenerationError(google.protobuf.message.Message):
    """E040"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___CatalogGenerationError: typing_extensions.TypeAlias = CatalogGenerationError

@typing.final
class CatalogGenerationErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CatalogGenerationError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CatalogGenerationError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CatalogGenerationErrorMsg: typing_extensions.TypeAlias = CatalogGenerationErrorMsg

@typing.final
class WriteCatalogFailure(google.protobuf.message.Message):
    """E041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_EXCEPTIONS_FIELD_NUMBER: builtins.int
    num_exceptions: builtins.int
    def __init__(
        self,
        *,
        num_exceptions: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_exceptions", b"num_exceptions"]) -> None: ...

Global___WriteCatalogFailure: typing_extensions.TypeAlias = WriteCatalogFailure

@typing.final
class WriteCatalogFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___WriteCatalogFailure: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___WriteCatalogFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___WriteCatalogFailureMsg: typing_extensions.TypeAlias = WriteCatalogFailureMsg

@typing.final
class CatalogWritten(google.protobuf.message.Message):
    """E042"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___CatalogWritten: typing_extensions.TypeAlias = CatalogWritten

@typing.final
class CatalogWrittenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CatalogWritten: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CatalogWritten | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CatalogWrittenMsg: typing_extensions.TypeAlias = CatalogWrittenMsg

@typing.final
class CannotGenerateDocs(google.protobuf.message.Message):
    """E043"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CannotGenerateDocs: typing_extensions.TypeAlias = CannotGenerateDocs

@typing.final
class CannotGenerateDocsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CannotGenerateDocs: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CannotGenerateDocs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CannotGenerateDocsMsg: typing_extensions.TypeAlias = CannotGenerateDocsMsg

@typing.final
class BuildingCatalog(google.protobuf.message.Message):
    """E044"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___BuildingCatalog: typing_extensions.TypeAlias = BuildingCatalog

@typing.final
class BuildingCatalogMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___BuildingCatalog: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___BuildingCatalog | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___BuildingCatalogMsg: typing_extensions.TypeAlias = BuildingCatalogMsg

@typing.final
class DatabaseErrorRunningHook(google.protobuf.message.Message):
    """E045"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOOK_TYPE_FIELD_NUMBER: builtins.int
    hook_type: builtins.str
    def __init__(
        self,
        *,
        hook_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hook_type", b"hook_type"]) -> None: ...

Global___DatabaseErrorRunningHook: typing_extensions.TypeAlias = DatabaseErrorRunningHook

@typing.final
class DatabaseErrorRunningHookMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___DatabaseErrorRunningHook: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___DatabaseErrorRunningHook | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DatabaseErrorRunningHookMsg: typing_extensions.TypeAlias = DatabaseErrorRunningHookMsg

@typing.final
class HooksRunning(google.protobuf.message.Message):
    """E046"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_HOOKS_FIELD_NUMBER: builtins.int
    HOOK_TYPE_FIELD_NUMBER: builtins.int
    num_hooks: builtins.int
    hook_type: builtins.str
    def __init__(
        self,
        *,
        num_hooks: builtins.int = ...,
        hook_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hook_type", b"hook_type", "num_hooks", b"num_hooks"]) -> None: ...

Global___HooksRunning: typing_extensions.TypeAlias = HooksRunning

@typing.final
class HooksRunningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___HooksRunning: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___HooksRunning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___HooksRunningMsg: typing_extensions.TypeAlias = HooksRunningMsg

@typing.final
class FinishedRunningStats(google.protobuf.message.Message):
    """E047"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAT_LINE_FIELD_NUMBER: builtins.int
    EXECUTION_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    stat_line: builtins.str
    execution: builtins.str
    execution_time: builtins.float
    def __init__(
        self,
        *,
        stat_line: builtins.str = ...,
        execution: builtins.str = ...,
        execution_time: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution", b"execution", "execution_time", b"execution_time", "stat_line", b"stat_line"]) -> None: ...

Global___FinishedRunningStats: typing_extensions.TypeAlias = FinishedRunningStats

@typing.final
class FinishedRunningStatsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___FinishedRunningStats: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___FinishedRunningStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FinishedRunningStatsMsg: typing_extensions.TypeAlias = FinishedRunningStatsMsg

@typing.final
class ConstraintNotEnforced(google.protobuf.message.Message):
    """E048"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_FIELD_NUMBER: builtins.int
    ADAPTER_FIELD_NUMBER: builtins.int
    constraint: builtins.str
    adapter: builtins.str
    def __init__(
        self,
        *,
        constraint: builtins.str = ...,
        adapter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter", b"adapter", "constraint", b"constraint"]) -> None: ...

Global___ConstraintNotEnforced: typing_extensions.TypeAlias = ConstraintNotEnforced

@typing.final
class ConstraintNotEnforcedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConstraintNotEnforced: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConstraintNotEnforced | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConstraintNotEnforcedMsg: typing_extensions.TypeAlias = ConstraintNotEnforcedMsg

@typing.final
class ConstraintNotSupported(google.protobuf.message.Message):
    """E049"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_FIELD_NUMBER: builtins.int
    ADAPTER_FIELD_NUMBER: builtins.int
    constraint: builtins.str
    adapter: builtins.str
    def __init__(
        self,
        *,
        constraint: builtins.str = ...,
        adapter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter", b"adapter", "constraint", b"constraint"]) -> None: ...

Global___ConstraintNotSupported: typing_extensions.TypeAlias = ConstraintNotSupported

@typing.final
class ConstraintNotSupportedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConstraintNotSupported: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConstraintNotSupported | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConstraintNotSupportedMsg: typing_extensions.TypeAlias = ConstraintNotSupportedMsg

@typing.final
class TypeCodeNotFound(google.protobuf.message.Message):
    """E050"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_CODE_FIELD_NUMBER: builtins.int
    type_code: builtins.int
    def __init__(
        self,
        *,
        type_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type_code", b"type_code"]) -> None: ...

Global___TypeCodeNotFound: typing_extensions.TypeAlias = TypeCodeNotFound

@typing.final
class TypeCodeNotFoundMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___TypeCodeNotFound: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___TypeCodeNotFound | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___TypeCodeNotFoundMsg: typing_extensions.TypeAlias = TypeCodeNotFoundMsg



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/insights.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_telemetry_contexts_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__telemetry__contexts__pb2
from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-dbtlabs/proto/public/v1/events/insights.proto\x12\x19v1.public.events.insights\x1a>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xac\x01\n\x08PageLoad\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb3\x01\n\x0f\x43\x61talogLiteOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb4\x01\n\x10QueryHistoryOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb1\x01\n\rBookmarksOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb8\x01\n\x14\x42ookmarksOpenDetails\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb8\x01\n\x14\x42ookmarksEditDetails\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb6\x01\n\x12VersionHistoryOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xaf\x01\n\x0b\x43opilotOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb5\x01\n\x11\x43opilotCreateChat\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xce\x01\n\x0e\x43opilotAddCode\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x1a\n\x12\x63opilot_request_id\x18\x03 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xd3\x01\n\x13\x43opilotFeedbackGood\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x1a\n\x12\x63opilot_request_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xd2\x01\n\x12\x43opilotFeedbackBad\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x1a\n\x12\x63opilot_request_id\x18\x03 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xae\x01\n\nChartsOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb4\x01\n\x10\x43hartsConfigOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb3\x01\n\x0fShareCreateLink\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb1\x01\n\rShareOpenLink\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb7\x01\n\x13ShareCopyToNewQuery\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xc8\x01\n\x0b\x43svDownload\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x17\n\x0f\x66ile_size_bytes\x18\x03 \x01(\x05:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xcc\x01\n\x08RunQuery\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12[\n\x07\x63ontext\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x0b\n\x03sql\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xba\x01\n\x16HandoffOpenSqlInStudio\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xba\x01\n\x16HandoffOpenSqlInCanvas\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xbd\x01\n\x19HandoffOpenModelInCatalog\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xc4\x01\n Acknowledge2025LaunchTrialBanner\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42<Z:github.com/dbt-labs/proto-golang/v1/public/events/insightsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.insights_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dbt-labs/proto-golang/v1/public/events/insights'
  _globals['_PAGELOAD']._loaded_options = None
  _globals['_PAGELOAD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CATALOGLITEOPEN']._loaded_options = None
  _globals['_CATALOGLITEOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_QUERYHISTORYOPEN']._loaded_options = None
  _globals['_QUERYHISTORYOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_BOOKMARKSOPEN']._loaded_options = None
  _globals['_BOOKMARKSOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_BOOKMARKSOPENDETAILS']._loaded_options = None
  _globals['_BOOKMARKSOPENDETAILS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_BOOKMARKSEDITDETAILS']._loaded_options = None
  _globals['_BOOKMARKSEDITDETAILS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_VERSIONHISTORYOPEN']._loaded_options = None
  _globals['_VERSIONHISTORYOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTOPEN']._loaded_options = None
  _globals['_COPILOTOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTCREATECHAT']._loaded_options = None
  _globals['_COPILOTCREATECHAT']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTADDCODE']._loaded_options = None
  _globals['_COPILOTADDCODE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTFEEDBACKGOOD']._loaded_options = None
  _globals['_COPILOTFEEDBACKGOOD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTFEEDBACKBAD']._loaded_options = None
  _globals['_COPILOTFEEDBACKBAD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CHARTSOPEN']._loaded_options = None
  _globals['_CHARTSOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CHARTSCONFIGOPEN']._loaded_options = None
  _globals['_CHARTSCONFIGOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_SHARECREATELINK']._loaded_options = None
  _globals['_SHARECREATELINK']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_SHAREOPENLINK']._loaded_options = None
  _globals['_SHAREOPENLINK']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_SHARECOPYTONEWQUERY']._loaded_options = None
  _globals['_SHARECOPYTONEWQUERY']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CSVDOWNLOAD']._loaded_options = None
  _globals['_CSVDOWNLOAD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_RUNQUERY']._loaded_options = None
  _globals['_RUNQUERY']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFOPENSQLINSTUDIO']._loaded_options = None
  _globals['_HANDOFFOPENSQLINSTUDIO']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFOPENSQLINCANVAS']._loaded_options = None
  _globals['_HANDOFFOPENSQLINCANVAS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFOPENMODELINCATALOG']._loaded_options = None
  _globals['_HANDOFFOPENMODELINCATALOG']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._loaded_options = None
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_PAGELOAD']._serialized_start=239
  _globals['_PAGELOAD']._serialized_end=411
  _globals['_CATALOGLITEOPEN']._serialized_start=414
  _globals['_CATALOGLITEOPEN']._serialized_end=593
  _globals['_QUERYHISTORYOPEN']._serialized_start=596
  _globals['_QUERYHISTORYOPEN']._serialized_end=776
  _globals['_BOOKMARKSOPEN']._serialized_start=779
  _globals['_BOOKMARKSOPEN']._serialized_end=956
  _globals['_BOOKMARKSOPENDETAILS']._serialized_start=959
  _globals['_BOOKMARKSOPENDETAILS']._serialized_end=1143
  _globals['_BOOKMARKSEDITDETAILS']._serialized_start=1146
  _globals['_BOOKMARKSEDITDETAILS']._serialized_end=1330
  _globals['_VERSIONHISTORYOPEN']._serialized_start=1333
  _globals['_VERSIONHISTORYOPEN']._serialized_end=1515
  _globals['_COPILOTOPEN']._serialized_start=1518
  _globals['_COPILOTOPEN']._serialized_end=1693
  _globals['_COPILOTCREATECHAT']._serialized_start=1696
  _globals['_COPILOTCREATECHAT']._serialized_end=1877
  _globals['_COPILOTADDCODE']._serialized_start=1880
  _globals['_COPILOTADDCODE']._serialized_end=2086
  _globals['_COPILOTFEEDBACKGOOD']._serialized_start=2089
  _globals['_COPILOTFEEDBACKGOOD']._serialized_end=2300
  _globals['_COPILOTFEEDBACKBAD']._serialized_start=2303
  _globals['_COPILOTFEEDBACKBAD']._serialized_end=2513
  _globals['_CHARTSOPEN']._serialized_start=2516
  _globals['_CHARTSOPEN']._serialized_end=2690
  _globals['_CHARTSCONFIGOPEN']._serialized_start=2693
  _globals['_CHARTSCONFIGOPEN']._serialized_end=2873
  _globals['_SHARECREATELINK']._serialized_start=2876
  _globals['_SHARECREATELINK']._serialized_end=3055
  _globals['_SHAREOPENLINK']._serialized_start=3058
  _globals['_SHAREOPENLINK']._serialized_end=3235
  _globals['_SHARECOPYTONEWQUERY']._serialized_start=3238
  _globals['_SHARECOPYTONEWQUERY']._serialized_end=3421
  _globals['_CSVDOWNLOAD']._serialized_start=3424
  _globals['_CSVDOWNLOAD']._serialized_end=3624
  _globals['_RUNQUERY']._serialized_start=3627
  _globals['_RUNQUERY']._serialized_end=3831
  _globals['_HANDOFFOPENSQLINSTUDIO']._serialized_start=3834
  _globals['_HANDOFFOPENSQLINSTUDIO']._serialized_end=4020
  _globals['_HANDOFFOPENSQLINCANVAS']._serialized_start=4023
  _globals['_HANDOFFOPENSQLINCANVAS']._serialized_end=4209
  _globals['_HANDOFFOPENMODELINCATALOG']._serialized_start=4212
  _globals['_HANDOFFOPENMODELINCATALOG']._serialized_end=4401
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._serialized_start=4404
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._serialized_end=4600
# @@protoc_insertion_point(module_scope)
